@@ -2,7 +2,7 @@ from pathlib import Path
 from threading import Semaphore
 from typing import Optional, Union
 
-from tree_sitter import Language
+from tree_sitter import Language, Parser
 
 _PACKAGE = Path(__file__).parent
 
@@ -10,6 +10,16 @@ _BUILD_INPUT = _PACKAGE / "src"
 _BUILD_TARGET = "python-language.so"
 
 _language_cache: Optional[Language] = None
+_parser_cache: Optional[Parser] = None
+
+
+def py_parser(rebuild: bool = False) -> Parser:
+    global _parser_cache
+    if _parser_cache is None:
+        _parser_cache = Parser()
+        _parser_cache.set_language(py_language(rebuild=rebuild))
+    assert isinstance(_parser_cache, Parser), "parser must not be None by now"
+    return _parser_cache
 
 
 def py_language(rebuild: bool = False) -> Language:
@@ -19,7 +29,7 @@ def py_language(rebuild: bool = False) -> Language:
             build_python_language(rebuild=rebuild, build_lib=_PACKAGE),
             "python",
         )
-    assert _language_cache, "this should exist"
+    assert isinstance(_language_cache, Language), "language must not be None by now"
     return _language_cache
 
 
